#
# spec file for package python-jupyterlab
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distversion 4.2.5
Name:           python-jupyterlab
Version:        4.2.5
Release:        1.1
Summary:        Environment for interactive and reproducible computing
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyterlab/jupyterlab
Source0:        https://files.pythonhosted.org/packages/source/j/jupyterlab/jupyterlab-%{version}.tar.gz
Source99:       python-jupyterlab-rpmlintrc
BuildRequires:  %{python_module Jinja2 >= 3.0.3}
BuildRequires:  %{python_module async_lru >= 1.0.0}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch-jupyter-builder}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module httpx >= 0.25.0}
BuildRequires:  %{python_module importlib-metadata >= 4.8.3 if %python-base < 3.10}
BuildRequires:  %{python_module importlib-resources >= 1.4 if %python-base < 3.9}
BuildRequires:  %{python_module ipykernel >= 6.5.0}
BuildRequires:  %{python_module jupyter-lsp >= 2.0.0}
BuildRequires:  %{python_module jupyter_core}
BuildRequires:  %{python_module jupyter_server >= 2.4.0 with %python-jupyter_server < 3}
BuildRequires:  %{python_module jupyterlab_server >= 2.27.1 with %python-jupyterlab_server < 3}
BuildRequires:  %{python_module notebook_shim >= 0.2}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 40.1}
BuildRequires:  %{python_module tomli >= 1.2.2 if %python-base < 3.11}
BuildRequires:  %{python_module tornado >= 6.2.0}
BuildRequires:  %{python_module traitlets}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       jupyter-jupyterlab = %{version}
Requires:       python-Jinja2 >= 3.0.3
Requires:       python-async_lru >= 1.0.0
Requires:       python-httpx >= 0.25.0
Requires:       python-ipykernel >= 6.5.0
Requires:       python-jupyter-lsp >= 2.0.0
Requires:       python-jupyter_core
Requires:       python-notebook_shim >= 0.2
Requires:       python-packaging
Requires:       python-setuptools >= 40.1
Requires:       python-tornado >= 6.2.0
Requires:       python-traitlets
Requires:       (python-importlib-metadata >= 4.8.3 if python-base < 3.10)
Requires:       (python-importlib-resources >= 1.4 if python-base < 3.9)
Requires:       (python-jupyter_server >= 2.4.0 with python-jupyter_server < 3)
Requires:       (python-jupyterlab_server >= 2.27.1 with python-jupyterlab_server < 3)
Requires:       (python-tomli >= 1.2.2 if python-base < 3.11)
Suggests:       python-jupyter-collaboration >= 1
Provides:       python-jupyter_jupyterlab = %{version}
Obsoletes:      python-jupyter_jupyterlab < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module jupyterlab-server-test}
BuildRequires:  %{python_module pytest >= 7.0}
BuildRequires:  %{python_module pytest-check-links}
BuildRequires:  %{python_module pytest-console-scripts}
BuildRequires:  %{python_module pytest-jupyter >= 0.5.3}
BuildRequires:  %{python_module pytest-tornasync}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module virtualenv}
# /SECTION
%python_subpackages

%description
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.).

%package     -n jupyter-jupyterlab
Summary:        Environment for interactive and reproducible computing
Group:          Development/Languages/Python
Requires:       jupyter-jupyterlab-filesystem
Requires:       nodejs >= 10
Requires:       npm >= 10
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(jupyterlab) = %{distversion}
Suggests:       python3-jupyterlab
Provides:       jupyter-jupyterlab-discovery = 6
Obsoletes:      jupyter-jupyterlab-discovery < 6

%description -n jupyter-jupyterlab
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.).

%prep
%autosetup -p1 -n jupyterlab-%{version}
sed -i -e 's|^#!%{_bindir}/env node|#!%{_bindir}/node|' jupyterlab/staging/yarn.js
chmod a+x jupyterlab/staging/yarn.js
find jupyterlab -name yarn.lock -delete
find jupyterlab -name .yarnrc.yml -delete

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand #
%fdupes %{buildroot}%{$python_sitelib}
}
%fdupes %{buildroot}%{_jupyter_prefix}
%python_clone -a %{buildroot}%{_bindir}/jupyter-lab
%python_clone -a %{buildroot}%{_bindir}/jupyter-labextension
%python_clone -a %{buildroot}%{_bindir}/jupyter-labhub
%python_clone -a %{buildroot}%{_bindir}/jlpm
%suse_update_desktop_file jupyterlab

%check
# This is only a rudimentary set of tests which we can run offline using pytest directly. The full test
# suite would use jlpm which needs online connection through npm:
# https://jupyterlab.readthedocs.io/en/stable/developer/contributing.html#build-and-run-the-tests
# Disable build checks that pull in remote resources with npm
donttest="$donttest or (TestExtension and test_app_dir)"
donttest="$donttest or (TestExtension and test_build)"
donttest="$donttest or (TestExtension and test_disable_extension)"
donttest="$donttest or (TestExtension and test_enable_extension)"
donttest="$donttest or (TestExtension and test_list_extension)"
donttest="$donttest or (TestExtension and test_link)"
donttest="$donttest or (TestExtension and test_unlink)"
donttest="$donttest or (TestExtension and test_install)"
donttest="$donttest or (TestExtension and test_uninstall)"
donttest="$donttest or (TestExtension and test_update)"
donttest="$donttest or (TestAppHandlerRegistry and test_get_registry)"
donttest="$donttest or (TestAppHandlerRegistry and test_populate_staging)"
donttest="$donttest or (TestAppHandlerRegistry and test_yarn_config)"
donttest="$donttest or (TestBuildAPI and test_build)"
%pytest -k "not (${donttest:4} ${$python_donttest})"

%post
%python_install_alternative jupyter-lab jupyter-labextension jupyter-labhub jlpm

%postun
%python_uninstall_alternative jupyter-lab

%files %{python_files}
%license LICENSE
%{python_sitelib}/jupyterlab/
%{python_sitelib}/jupyterlab-%{version}.dist-info/
%python_alternative %{_bindir}/jupyter-lab
%python_alternative %{_bindir}/jupyter-labextension
%python_alternative %{_bindir}/jupyter-labhub
%python_alternative %{_bindir}/jlpm

%files -n jupyter-jupyterlab
%license LICENSE
%{_jupyter_config} %{_jupyter_servextension_confdir}/jupyterlab.json
%{_jupyter_config} %{_jupyter_server_confdir}/jupyterlab.json
%{_jupyter_lab_dir}
%{_datadir}/applications/jupyterlab.desktop
%{_datadir}/icons/hicolor/scalable/apps/jupyterlab.svg

%changelog
* Wed Aug 28 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.2.5
  * Use locale name instead of display/native name to toggle
    language #16710 (@maitreya2954)
  * Prevent replacing code with find and replace in read-only cells
    [#16682] (@itsmevichu)
  * Do not block shift-click mouse up handler on active cell #16647
    (@EdsterG)
* Wed Aug 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.2.4
  * Fix the identifier to download licenses in JSON format #16584
    (@joaopalmeiro)
  * Update JupyterLab wordmark color #16567 (@joaopalmeiro)
  * Add customisation options to prevent inline completer resizing
    aggressively #16507 (@krassowski)
  * Fix license table CSS selector to apply the selected row styles
    [#16547] (@joaopalmeiro)
* Fri Jul 12 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.2.3
  * Fix inline completer configure calls not being propagated
    correctly #16508 (@krassowski)
  * Fix the lines placeholder taking up too much space #16493
    (@krassowski)
  * Use correct hub restart URL #16471 (@mahendrapaipuri)
  * Fix check link CI failure in README (time zone converter site)
    [#16482] (@afshin)
- Release 4.2.2
  [#]# Bugs fixed
  * Fix width and margins of the notebook footer. #16383
    (@HaudinFlorence)
  * Fix async function display #16443 (@sanskriti2005)
  * Fix code comments in tilde (~) fences incorrectly shown as
    headings in TOC #16437 (@itsmevichu)
  * Fix typos in jupyter-collaboration-missing error message #16436
    (@krishanbhasin-px)
  * Reactive toolbar computation, again... #16409 (@brichet)
  * Fix comments in nested markdown code blocks incorrectly being
    identified as TOC headings #16420 (@itsmevichu)
  * Add the toolbar again when updating the title of
    PanelWithToolbar #16390 (@brichet)
  * Align token usage for events #16397 (@fcollonval)
  * Fix runtime console error in debugger extension #16368
    (@afshin)
  [#]# Maintenance and upkeep improvements
  * Ignore empty stdout data when logging in verdaccio #16459
    (@fcollonval)
  * Fix some flaky ui tests #16430 (@brichet)
  * Do not install cairo/pango on Mac in CI #16434 (@krassowski)
  * Fix usage check job on CI (add setuptools dependency) #16423
    (@jtpio)
  * Run Python tests on MacOS with Python 12, replace canvas with
    jest-canvas-mock #16314 (@krassowski)
  * Fix failing link check (point to JAWS on Wikipedia) #16365
    (@krassowski)
  * Do not check links to Jupyter blog on Medium #16351
    (@krassowski)
- Release 4.2.1
  * Fix Shift + Tab contextual help inspector tooltip regression
    [#16343] (@krassowski)
  * Fix workspace context menu incorrectly showing up in other
    sidebar sections #16346 (@krassowski)
  * Fix execution in console in terminal interaction mode #16348
    (@krassowski)
  * Reactive toolbar: avoid simultaneous calls to _onResize()
    [#16335] (@brichet)
  * Resetting a shortcut does not restore and enable the default if
    it was modified #16304 (@itsmevichu)
  * Allow to invoke inline completer anywhere (not only at the end
    of line) #16298 (@ajbozarth)
  * Search and replace with substring in markdown and raw cells
    [#16293] (@JasonWeill)
  * Wait for the cell toolbar items to be rendered the first time
    before looking for overlap #16291 (@brichet)
  * Add lowercase proxy vars and make priority consistent with
    other tools #16287 (@jgoodson)
* Thu May  9 2024 Ben Greiner <code@bnavigator.de>
- Revert to 4.1.8 until the ecosystem is ready (notebook)
* Thu May  9 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.2.0
  * WorkspacesUI
  * Recently opened/closed files
  * Full notebook windowing mode by default
  * Improved Shortcuts Editor
  * Dark high contrast theme
  * Keyboard shortcuts improvements
  [#]# Bugs fixed
  * Check the command is registered before calling
    notifyCommandChanged() #16273 (@jtpio)
  * Set aria-label to title if no label for #16262 (@fcollonval)
  * Fix changing font size in text editor #16261 (@FoSuCloud)
  * Fix replace when replacement text matches source text multiple
    times #16258 (@JasonWeill)
  * Add reopen closed command to tab context menu #16250
    (@krassowski)
- Drop some directives working around the former whl install scheme
* Wed May  8 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build from source not whl from pypi.
* Fri May  3 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.1.8
  * Consider higher levels when toggling plugin #16251
    (@divyansshhh)
- Update to 4.1.7
  * Fix toggling extension at system level #16241 (@krassowski)
  * Fix extension toggling at different level #16102 (@divyansshhh)
  * Partial backport of windowing fix from #16013 #16202
    (@krassowski)
* Mon Apr 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.1.6
  * Fix outputarea collapse expand #16124 (@FoSuCloud)
  * Disable placeholder for password input #16128 (@Alanhou1222)
  * Fix for existing shortcuts getting triggered while edit
    shortcut #16126 (@Susilkessav)
  * Use smart scroll in debugger to minimize distraction #16084
    (@krassowski)
  * Store the real position of the item in reactive toolbar #16111
    (@brichet)
  * Fix extension installation on Windows #16064 (@fcollonval)
  * Removes dotted outline from active code cell #16070
    (@JasonWeill)
  * Long items should not wrap #15844 (@mdietz94)
  * Fix manager isDisposed is not set #15997 (@fcollonval)
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.1.5
  * Fix Theme color is not applied to Toolbar Button #15957
    (@FoSuCloud)
  * Uses the browser window's selection as the default search query
    [#15834] (@JasonWeill)
  * Show outline on the full item in file browser, only when needed
    [#15860] (@krassowski)
  * Short-circuit selectItemByName() if already selected #15970
    (@krassowski)
  * Fix browser-test.js #15892 (@fcollonval)
  * Avoid concurrency when computing the items in notebook toolbar
    [#15954] (@brichet)
  * Fixes filter for Chinese, other non-ASCII filenames #15935
    (@JasonWeill)
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.1.4
  * Fix creating files in custom drives, fix ContentsManagerMock
    [#15291] (@jtpio)
  * Fix Theme color is not applied to SwitchKernel ToolbarButton
    [#15924] (@FoSuCloud)
  * Revert "Prevent command shortcuts from preventing user input"
    [#15938] (@krassowski)
  * Fix spurious dedent when opening inspector tooltip #15898
    (@krassowski)
  * Add an explicit default for inline completer providers #15899
    (@krassowski)
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Release 4.1.3
  * Fix Pressing enter in console with console run keystroke set to
  enter creates a newline and runs #15869 (@FoSuCloud)
  * Fix saving of item positions in reactive toolbar #15843
  (@brichet)
  * Prevent command shortcuts from preventing user input #15790
  (@krassowski)
  * Fix missing signals in file editor adapter #15873 (@krassowski)
  * Fix codemirror highlight for Python builtin #15805 (@AllanChain)
  * When attaching only typeset after rendering is completed #15810
  (@krassowski)
- Release 4.1.2
  * Fix highlight sequencing when replacing text in code cells
    [#15803] (@JasonWeill)
  * Windows platforms, erratic pasting of text into Markdown field
    [#15794] (@kiliansinger)
  * Restore notebook scrolling on dragging a cell to the viewport
    edge #15782 (@krassowski)
  * Fix typing in editable elements inside of open shadow DOM
    [#15774] (@krassowski)
- Release 4.1.1
  * Correct Alt + number keyboard shortcuts command map #15791
    (@g547315)
  * Catch errors attempting to access document.cookie #15788
    (@minrk)
  * Fix undo/redo in console, fix undo/redo enabled state in file
    editor #15783 (@krassowski)
  * Fix console cells not becoming read-only after execution #15779
    (@krassowski)
  * Fix migration of command selectors for shortcuts #15762
    (@krassowski)
  * Disable (shift + ) alt + number shortcuts on Mac #15761
    (@krassowski)
  * Catch OSError in addition to PermissionError when sys_prefix is
    read-only #15756 (@dhml)
  * Fix completer auto-invoking on non-source changes #15753
    (@krassowski)
  * Fix outputs preservation on splitting cells #15751
    (@krassowski)
- Release 4.1
  * Full changelog for user-facing changes:
    https://jupyterlab.readthedocs.io/en/latest/getting_started/changelog.html#v4-1
  * Custom CSS
  * Diagrams in Markdown
  * Inline completer
  * Keyboard navigation improvements
  * Execution history in notebook
  * Opening files from tracebacks
  * Error indicator in the table of contents
  * Plugin Manager
  * Virtual scrollbar for notebook in windowed mode
  * Notifications
  * Full notebook windowing mode improvements
  * Search improvements
  * Moved plugins
- Release 4.0.12
  * Fix jupyterlab downgrade issue on extension installation #15650
    (@Sarthug99)
  * Fix search highlights removal on clearing input box #15690
    (@krassowski)
  * Add scroll margin to headings for better alignment #15703
    (@krassowski)
  * Fix shortcut UI failing on filtering when empty command is
    given #15695 (@krassowski)
  * Fix connection loop issue with standalone foreign document in
    LSP #15262 (@trungleduc)
  * Fix outputarea package from not detecting updates #15642
    (@MFA-X-AI)
- Skip python39: no longer supported since ipython 8.19 (through
  ipykernel)
* Sat Jan 20 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.0.11
  [#]# Security fixes
  * Potential authentication and CSRF tokens leak in JupyterLab
    (GHSA-44cc-43rp-5947) CVE-2024-22421
  * SXSS in Markdown Preview (GHSA-4m77-cmpx-vjc4) CVE-2024-22420
  [#]# Bugs fixed
  Fixes focus indicator on input checkbox for Firefox #15612
  (@alden-ilao)
- Update to 4.0.10
  [#]#  Bugs fixed
  * Backport PR #15386: Improve scrolling to heading #15565
    (@krassowski)
  * Workaround focus leaving input box on consecutive submissions
    [#15479] (@krassowski)
  * Fix search coming back in notebook and editor #15443
    (@krassowski)
  * Fix jupyter labextension watch --help #15542 (@akx)
  * Fix FormComponent showing error indicators in all fields when
    using a customValidate function #15464 (@mmichilot)
  * Fix Shift + L not working in stdin #15440 (@krassowski)
* Sun Nov 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.9
  [#]# Bugs fixed
  * Improve cell toolbar tracker #15314 (@fcollonval)
  * Do not update filebrowser breadcrumbs when not needed #15387
    (@krassowski)
  * Don't show default value for objects in Settings Editor #15380
    (@firai)
  * Fix highlighting search in an out-of-viewport cell #15376
    (@fcollonval)
  * Fix overreactive scrolling to next cell after Shift + Enter
    [#15288] (@krassowski)
  * Fix missing default property breaking codemirror overrides.json
    [#15346] (@LJMP)
  * Fix update button in extension manager #15331
    (@nbowditch-einblick)
  * Fix scrolling when dragging files in the file browser #15318
    (@krassowski)
  * Fix scrolling past long outputs in presence of un-rendered
    headings #15356 (@krassowski)
  * Update notebook window on resize if height changes #15357
    (@krassowski)
  * Remove unnecessary requirement from codemirror service plugin
    [#15362] (@paulkim3151)
- Release 4.0.8
  [#]# Enhancements made
  * Expand search box horizontally when text grows long #15266
    (@sinistersnare)
  [#]# Bugs fixed
  * Add min width to constrain resizing in side-by-side view #14529
    (@dharmaquark)
  * Fix collapsed cells styling #15322 (@fcollonval)
  * Fix autobrackets and other default CM extension #15297
    (@fcollonval)
  * Fix rulers position with gutter width #15296 (@fcollonval)
  * Declare Webpack loaders with require.resolve() #15299 (@tibdex)
* Wed Oct 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.7
  [#]# Enhancements made
  * Add the standard SQL mimetype #15180 (@brichet)
  [#]# Bugs fixed
  * Restore horizontal scrolling of outputs for Firefox #15171
    (@fcollonval)
  * Fix text wrapping in the search box #15080 (@eliaslma)
  * Fix completer documentation panel hiding and animation #15238
    (@krassowski)
  * Fix clicking in the TOC does not scroll #15184 (@parmentelat)
  * Hide completer when changing notebook tabs #14534
    (@nishikantparmariam)
  * Backport of MathJax double init/font URL fix and binder/log
    updates #15231 (@bollwyvl)
  * Restore syntax highlighting for mimetypes with more than one
    identifier #15175 (@jans-code)
  * Fix completer width inflation and jitter #15132 (@krassowski)
  * Fix Show Keyboard Shortcuts command #15170 (@jtpio)
  * Blur footer for any key that triggers a 'select above', not
    just ArrowUp #14796 (@smacke)
  * Fix background-color in <select> elements in dark theme #15098
    (@Rmarieta)
  * Fix selection in active line #15129 (@krassowski)
  * Remove unusedDocuments, fix culling of foreign documents #15105
    (@krassowski)
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.6
  [#]# Enhancements made
  * Add more LSP request types #15064 (@krassowski)
  * Expose processedItemsCache as a protected in CompleterModel
    [#15025] (@krassowski)
  * Fix filebrowser.open and add ability to provide a factory
    [#14983] (@fcollonval)
  * Use config compatible with notebook 7 #14978 (@fcollonval)
  [#]# Bugs fixed
  * Fix return type of getMimeTypeByLanguage() #15101 (@krassowski)
  * Fix documentation panel display logic of the completer #15106
    (@trungleduc)
  * Check applicable provider in ProviderReconciliator #15094
    (@trungleduc)
  * Completer: switch renderer & model on update, update on
    providers change #15065 (@krassowski)
  * Fix _updateConstraints missing protected/private classifier.
    [#15066] (@krassowski)
  * HoverBox: adjust right when moving node to fit within window
    [#15052] (@krassowski)
  * fixes codemirror settings #15009 (@andrewfulton9)
  * Pass completion context to shouldShowContinuousHint() #15015
    (@krassowski)
  * Fix translation syntax to extract it by the parser #14979
    (@fcollonval)
  * added title to Close tab icon #14973 (@j264415)
  [#]# Maintenance and upkeep improvements
  * Install playwright browser in jupyterlab.browser_check #15117
    (@brichet)
  * Enable Playwright trace #15087 (@jtpio)
  * Bump ruff from 0.0.282 to 0.0.286 #15056 (@dependabot[bot])
  * React on galata update comment, fix binder URL in docs #15070
    (@krassowski)
  * Deprecate LSP adapter getEditorIndexAt() method #15028
    (@krassowski)
  * Fix pepy.tech links #14982 (@fcollonval)
  * simplify binder python baseline #14971 (@bollwyvl)
  * Restore welcome test #14946 (@fcollonval)
  * Bump black[jupyter] from 23.3.0 to 23.7.0 #14893
    (@dependabot[bot])
  [#]# API and Breaking Changes
  * Check applicable provider in ProviderReconciliator #15094
    (@trungleduc)
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Demote primary flavor recommendation to suggestion
- Move entrypoints to python alternatives
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Recommend the primary python flavor -- boo#1214354
* Mon Aug 14 2023 Arun Persaud <arun@gmx.de>
- update to version 4.0.5:
  * Check backward dep (#14956)
  * Ensure not breaking backward compatibility (#14952)
  * Bump lumino packages (#14951)
  * Fix View Menu "Show line number" does not show its corresponding
    shortcut (#14950)
  * Make the browser check default_url configurable (#14949)
  * Allow opening links in new tabs when HTML is trusted (#14943)
  * Remove docker ignore file (#14938)
  * Fix broken link (#14940)
  * Make the DOM structure of linked output views more similar to
    outputs (#14941)
  * Custom script to upgrade staging/yarn.lock (#14935)
  * Rename readthedoc config (#14930)
  * Fix incorrect indentation browser_check.py (#14923)
* Sat Aug  5 2023 Arun Persaud <arun@gmx.de>
- update to version 4.0.4:
  * Enhancements made
    + Recommend major versions for Lab 3/Lab 4 compatible extensions
    [#14908] (@JasonWeill)
    + Improve upgrade extension script #14882 (@fcollonval)
    + Adds rank to ICompletionProvider #14800 (@hbcarlos)
    + Deprecates collaborative flag #14792 (@hbcarlos)
  * Bugs fixed
    + Fix semantic commands enabled status #14664 (@fcollonval)
    + In defer mode render enough cells to fill the viewport #14865
    (@fcollonval)
    + Fix CodeMirror tooltip positioning and tooltip background #14858
    (@krassowski)
    + Removes context data from shared model #14771 (@hbcarlos)
    + fix: out of order headings display in toc #14753 (@skyetim)
    + fix: update blocked extensions uris #14846 (@emmanuel-ferdman)
    + Fix CodeMirror theme selection background color #14841
    (@AllanChain)
    + Fix icon and theme/styles for grid in CSV/TSV viewer #14822
    (@krassowski)
    + Adds missing parameters to ICompleterProvider API #14809
    (@hbcarlos)
    + Adds this context when calling ICompletionProvider.modelFactory
    [#14812] (@hbcarlos)
    + Emit changed signal from output area when an output is updated
    [#14785] (@bollwyvl)
    + Improve typing to avoid bad usage of
    context.contentsModel.content #14660 (@fcollonval)
  * Maintenance and upkeep improvements
    + Fix integration tests #14886 (@fcollonval)
    + Bump stylelint from 14.16.1 to 15.10.1 #14802 (@dependabot[bot])
    + Relax Event.IManager interface #14770 (@trungleduc)
    + Bump word-wrap from 1.2.3 to 1.2.4 #14847 (@dependabot[bot])
    + Add style validator #14795 (@krassowski)
    + Bump semver from 7.3.8 to 7.5.2 #14750 (@dependabot[bot])
  * Documentation improvements
    + Recommend major versions for Lab 3/Lab 4 compatible extensions
    [#14908] (@JasonWeill)
    + Update yarn link documentation #14902 (@gabalafou)
    + Create JupyterLab 3.4.4 accessibility statement #14856
    (@isabela-pf)
    + Align copier version with the extension template #14899 (@jtpio)
    + Bump stylelint from 14.16.1 to 15.10.1 #14802 (@dependabot[bot])
    + Fix broken link to security model #14861 (@fcollonval)
    + Improve examples #14726 (@fcollonval)
- changes from version 4.0.3:
  * Bugs fixed
    + Fix incorrect CSS value for statusbar popover shadow #14789
    (@krassowski)
    + Fix indentation problem after multi-line Python function
    definition #14748 (@FoSuCloud)
    + Fix HTML lang being set to ‘default’ resulting in blind users
    with screenreader reading everything in German #14705
    (@andrii-i)
    + Expose serverCapabilities, provides, and updateLogging #14712
    (@krassowski)
    + Fix kernel message deserialization #14721 (@davidbrochart)
    + Ensure the kernel selector show the default kernel if notebook
    does not have a valid assigned kernel #14693 (@echarles)
    + Add a title to the Markdown Preview widget #14681 (@jtpio)
  * Maintenance and upkeep improvements
    + Separate LSP settings handling out to another plugin #14786
    (@krassowski)
    + fix changed username, pin pydantic<2 for CI #14780 (@bollwyvl)
    + Clean up obsolete docker #14729 (@fcollonval)
    + Port LSP connection manager fixes/enhancements #14714
    (@krassowski)
    + Drop StatusMessage which is dead code #14713 (@krassowski)
    + Update requirements: conda != Python, jupyter-server over
    notebook #14709 (@krassowski)
    + Don’t list log file as changes when checking license header
    [#14700] (@fcollonval)
    + Update branch configuration #14694 (@fcollonval)
    + Update the jupyter labextension list compat message #14680
    (@jtpio)
  * Documentation improvements
    + fix changed username, pin pydantic<2 for CI #14780 (@bollwyvl)
    + fix: typo in param annotation #14745 (@emmanuel-ferdman)
    + fix: typo in common extension points page #14727
    (@emmanuel-ferdman)
    + Fix docs for semantic commands registration #14718 (@jtpio)
    + Ensure documentation switcher data always points to the latest
    JSON. #14698 (@fcollonval)
    + Update requirements: conda != Python, jupyter-server over
    notebook #14709 (@krassowski)
    + Set out expectations for good first issue label #14686
    (@krassowski)
    + Update branch configuration #14694 (@fcollonval)
    + Update the jupyter labextension list compat message #14680
    (@jtpio)
    + Document more features for JupyterLab on Binder #14677
    (@fcollonval)
    + Fix copier command in documentation #14671 (@fcollonval)
    + Update contributing.rst for Windows users #14666 (@coriegulik)
  * Other merged PRs
    + fix: typo in notifications settings documentation #14747
    (@holzman)
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.2
  * Add support for copier 8.0.0 #14644 (@fcollonval)
  * Update documentation snapshots #14636 (@fcollonval)
  * Allow Lumino 1.x version for rendermime-interfaces #14618
    (@fcollonval)
- Release 4.0.1
  [#]# Enhancements made
  * Enable base numbering option #14586 (@tuncbkose)
  * added dynamic functionality to the text spacing #14561
    (@j264415)
  * Implement dialog element for dialogs with accessibility #14560
    (@t03857785)
  * Allow maxHeight being equal to minHeight for HoverBox’s
    visibility #14533 (@nishikantparmariam)
  * FileBrowser: Added the sortNotebooksFirst option #14497
    (@tpatel)
  [#]# Bugs fixed
  * Inherit font family from .cm-editor #14601 (@krassowski)
  * Fix: Toolbar doesn’t update on paste. #14596 (@brijsiyag)
  * Highlight booleans using the same style as keywords #14588
    (@krassowski)
  * Avoid clearing the host node while rendering Markdown #14579
    (@c3Vu)
  * Fix react error log in shortcuts dialog #14566 (@c3Vu)
  * Updates docs to reflect that v4 is released #14556
    (@JasonWeill)
  * Fix drive handling for sessions and terminals #14519
    (@fcollonval)
- Release 4.0.0 highlights
  * New text editor
  * New extension manager
  * Improved document search
  * UI improvements
  * Accessibility improvements
  * Performance enhancements
  * Real Time Collaboration (now optional)
  * Full changelog:
    https://jupyterlab.readthedocs.io/en/latest/getting_started/changelog.html#v4-0
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.6.3
  * Bump lumino 1.x #14286 (@fcollonval)
  * Provide @jupyterlab/shared-models as singleton #14229
    (@fcollonval)
* Mon Mar 20 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.6.2
  * Fix save as without changing the file name #14212 (@hbcarlos)
  * Fix save as in collaborative mode #14182 (@hbcarlos)
  * Fix non-document wide undo stack #14063 (@fcollonval)
  * Fix code/content/ui font-size change #14077 (@FoSuCloud)
  * Restore @jupyterlab/shared-models as proxy to @jupyter/ydoc
    [#14133] (@fcollonval)
  * Doc session #14128 (@hbcarlos)
  * Use local paths instead of driveName:path in the shared model
    [#13866] (@hbcarlos)
  * use singleton boolean type for codemirror lineWiseCopyCut
    setting #14055 (@bollwyvl)
  * Fix integrity #14226 (@fcollonval)
  * Increases timeout #14045 (@brichet)
  * Use Python 3.11 for js-debugger tests #13941 (@fcollonval)
  * Fix verdaccio start up with nodejs 18.14.0 #13959 (@fcollonval)
* Sun Feb  5 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.6.1
  * Revert target to ES2017 #13914 (@fcollonval)
- Update to 3.6.0
  [#]# New features added
  * Add copy and paste commands to terminal context menu #13535
    (@krassowski)
  * Turn terminal links into anchors using xterm addon #13645
    (@mgcth)
  * Allows to pause the execution during debug #13494 (@brichet)
  * Ask confirmation when closing a document #13489 (@fcollonval)
  * Add events service #13465 (@fcollonval)
  * Add notification queue and display using toast #12959
    (@telamonian)
  * Add announcements #13444 (@fcollonval)
  * Add line history to Stdin cell outputs #13431 (@fcollonval)
  * Add user configuration for additional schemes for the sanitizer
    plugin #13419 (@fcollonval)
  * User service #12926 (@hbcarlos)
  [#]# Enhancements made
  * Expose contentVisibility widget hiding mode #13860
    (@fcollonval)
  * default locale will use OS default locale #13721 (@fcollonval)
  * Enable strict CSS containment for MainAreaWidget #13811
    (@krassowski)
  * User defined default viewer take precedence for rendered
    factory #11541 (@fcollonval)
  * Remove not needed Completer.IRenderer.sanitizer #13700
    (@fcollonval)
  * Contain the tabs within the tabbar (do not use translation
    transform) #13671 (@krassowski)
  * Sanitize notification message #13510 (@fcollonval)
  * Use more the contextual collaborative model attribute #13564
    (@fcollonval)
  * Add lumino with support for plugin deactivation #13541
    (@fcollonval)
  * Sets whether the model is collaborative or not when registering
    its factory #13526 (@hbcarlos)
  * RTC: Move user name to user panel #13517 (@martinRenou)
  * jupyter_server_ydoc>=0.6.0,<0.7.0 #13499 (@fcollonval)
  * Define file or activity icons color as static #13408
    (@fcollonval)
  * Added collaborative_document_save_de… #13404 (@fcollonval)
  * Add a hover effect to plugin list entries #13384 (@krassowski)
  * Bump Lumino 1.x #13378 (@fcollonval)
  * Store original path as returned from contents API in the
    Contents.IModel #13216 (@krassowski)
  * Update document dirty logic for RTC #13364 (@davidbrochart)
  * Store document info in the state not in a separate context map
    out of the document interface. #13317 (@fcollonval)
  * Use file ID #13246 (@davidbrochart)
  * Relax doc provider API #13214 (@fcollonval)
  * Avoids restoring widget in dock panel when first loading in
    'single-document' mode #13314 (@brichet)
  * Fix illegible white on yellow text of stacktrace in dark theme
    [#13249] (@NikolayXHD)
  * Use settings icons for 6 plugins #13298 (@krassowski)
  * Do not run galata in .ipynb_checkpoints #13297 (@krassowski)
  * Allow empty notebook #13296 (@martinRenou)
  * Optimize text mimerenderer: ansi vs autolink #13202 (@vidartf)
  * Remove Yjs locking mechanism #13222 (@davidbrochart)
  [#]# Bugs fixed
  * Define colour and background for filebrowser edit field #13895
    (@krassowski)
  * Reset execution indicator state when kernel restarts #13832
    (@krassowski)
  * Restore blueprint focus overrides on 3.x branch #13879
    (@krassowski)
  * Restore partial border effect for menu #13878 (@krassowski)
  * Pin jupyter_ydoc #13863 (@fcollonval)
  * Fix preferred_dir for examples #13788 (@fcollonval)
  * Bump canvas to version with nodejs 18 binaries #13783
    (@fcollonval)
  * Explain why cell model may be missing in cell toolbar #13763
    (@krassowski)
  * Fix handling of settingEditorType #13761 (@jtpio)
  * Fix execution indicator in RTC mode #13693 (@trungleduc)
  * Force jupyter-server v1 to check against notebook v6 #13716
    (@fcollonval)
  * Write the browser open files for test #13634 (@fcollonval)
  * Add the scaleFactor value from the embed options when creating
    the PNG representation for a Vega-based chart #13610
    (@joaopalmeiro)
  * Does not prevent default behavior when shift-clicking #13616
    (@jmk89)
  * Do not load CSS of disabled federated extensions #11962
    (@jtpio)
  * use jupyter_config_dir instead of config_path[0] for
    workspaces, settings #13589 (@minrk)
  * Bump @lumino/application #13590 (@fcollonval)
  * Restores the appearance of the settingeditor's input focus
    [#13554] (@brichet)
  * Fix a wrong argument when calling 'renderMimeVariable' #13531
    (@brichet)
  * fix size of toc running indicator #13568 (@uenot)
  * Fixes backward-incompatible changes for 3.6 #13560 (@hbcarlos)
  * Make focus visible (mostly CSS) #13415 (@gabalafou)
  * Set corrections to icons and switch colors #13500
    (@HaudinFlorence)
  * Default IDocumentProviderFactory.IOptions generic to
    ISharedDocument #13490 (@jtpio)
  * Use same key for saving user info in local store #13482
    @hbcarlos
* Mon Dec 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.5.2
  * use jupyter_config_dir instead of config_path[0] for
    workspaces, settings #13589 (@minrk)
  * Fix Python test dependencies #13508 (@fcollonval)
- Release 3.5.1
  * Fixes sharing metadata #13491 (@hbcarlos)
  * Bump sanitize-html to 2.7.3 #13509 (@fcollonval)
* Wed Oct 26 2022 Ben Greiner <code@bnavigator.de>
- update to version 3.5.0
  * Enhancements made
    + Optimize text mimerenderer: ansi vs autolink #13202
    (@vidartf)
    + Collapse debugger panel when disabling debugger #13088
    (@yanmulin)
    + File Browser: add support for filtering directories on search
    [#12342] (@jtpio)
    + Prompt for renaming at first manual save #12953 (@fcollonval)
    + Raise ceiling on jupyter_server dependency to < 3 #13068
    (@Zsailer)
  * Bugs fixed
    + Set isUntitled to false on document path changes #13268
    (@fcollonval)
    + Don't dispose the notebook metadata editor on active cell
    change #13259 (@fcollonval)
    + Use keystroke format consistent with menus #13200
    (@fcollonval)
  * Maintenance and upkeep improvements
    + Fix memory leaks #13229 (@fcollonval)
    + Bump to the latest Lumino 1.x #13190 (@fcollonval)
    + Update branch configuration #13184 (@fcollonval)
* Sun Oct  9 2022 Arun Persaud <arun@gmx.de>
- update to version 3.4.8:
  * Enhancements made
    + Adjust CSS styles degrading performance in Chromium browsers
    [#13159] (@krassowski)
  * Bugs fixed
    + Always show tooltip in hover box even if edges are out of view
    [#13161] (@krassowski)
    + Fix workspace URL while cloning a workspace #12794
    (@aditya211935)
    + Switch back to display to hide tabs #13103 (@fcollonval)
    + Preserve kernel icon aspect ratio #13122 (@fcollonval)
    + Fix cell toolbar layout #13059 (@kulsoomzahra)
    + Avoid menus overflowing in small screens #13109 (@steff456)
  * Maintenance and upkeep improvements
    + Fix storybook error #13135 (@fcollonval)
    + Remove xeus-python installation for debugger test #13113
    (@fcollonval)
    + Resolve core_path before calling nodejs #13126 (@fcollonval)
* Tue Sep 13 2022 Arun Persaud <arun@gmx.de>
- update to version 3.4.7:
  * Enhancements made
    + Get package name from pyproject if available #13076 (@blink1073)
    + Fix blurry icons in Launcher at 400%% Zoom #13065 (@fcollonval)
  * Bugs fixed
    + Added mimeType for .webp image files #13066 (@alec-kr)
    + Fix URL when falling back to node-fetch #13067 (@fcollonval)
    + Keep completer visible when anchor is horizontally scrolled out
    of view #13046 (@krassowski)
* Thu Sep  8 2022 Arun Persaud <arun@gmx.de>
- update to version 3.4.6:
  * Bugs fixed
    + Update Python icon to be PSF Trademark compliant #13044
    (@fcollonval)
    + Reorder of webpackConfig merge #13042 (@fcollonval)
    + Update xterm.js dependency #13036 (@fcollonval)
    + Support stateStorage for API calls #13015 (@fcollonval)
    + Conditional call to waitIsReady in reload #13011 (@fcollonval)
    + Add scrolling to debugger variable renderer #12968 (@firai)
    + Fix resizing and selection of debugger variable explorer grid
    [#12943] (@firai)
  * Maintenance and upkeep improvements
    + Fix lumino API documentation links #13021 (@fcollonval)
  * Documentation improvements
    + Fix lumino API documentation links #13021 (@fcollonval)
* Thu Aug 11 2022 Arun Persaud <arun@gmx.de>
- update to version 3.4.5:
  * Enhancements made
    + Add an option to enable “fast checks” of the jupyter lab
    build. #12844 (@thetorpedodog)
    + Add .webp filetype in docRegistry. #12839 (@yangql176)
  * Bugs fixed
    + Only show “Shut Down Kernel” if kernel is running #12919
    (@krassowski)
    + Fix JSON Settings Editor #12892 (@krassowski)
    + Fix progress bar not working after uploading multiple files
    finished #12871 (@hsuanxyz)
    + Fix kernel in the statusbar does not match the actual #12865
    (@hsuanxyz)
    + Adjust css to not leave trace of deleted widgets #12838
    (@thomasaarholt)
  * Maintenance and upkeep improvements
    + Log launcher error to console #12909 (@trungleduc)
  * Documentation improvements
    + Add alt text to documentation #12879 (@isabela-pf)
    + Split commands in two blocks in the contributing guide #12898
    (@jtpio)
    + Remove reference to unmaintained nb_conda_kernels #12878
    (@SylvainCorlay)
    + Document building JupyterLab on osx-arm64 platforms #12882
    (@SylvainCorlay)
    + Don’t suggest deprecated command #12855 (@ryanlovett)
* Mon Aug  1 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.4.4
  Enhancements made
  * Adds version maintenance policy #12829 (@jweill-aws)
  * Increase title width in simple mode #11546 (@SylvainCorlay)
  * Bump xtermjs to latest #12715 (@yuvipanda)
  * Debugger: Make kernel source list react based #12751 (@vidartf)
  * Optimize debugger editor eachLine loops #12746 (@vidartf)
  * Make password inputs not give away how many characters were
    typed #12659 (@jasongrout)
  Bugs fixed
  * Remove drive prefix from the file path when creating the new
    path #12824 (@hbcarlos)
  * Use path to extract tmpPath #12823 (@fcollonval)
  * update tab name after file rename #12791 (@RobbyPratl)
  * Update base.css #12783 (@siddartha-10)
  * Pin nbclassic below 0.4.0 #12767 (@fcollonval)
  * Set focus when active cell changes only from mouse click #12735
    (@fcollonval)
  * Fix staging/yarn.lock registry #12742 (@vidartf)
  * Debugger: Fix CSS for variables inspecting #12749
    (@martinRenou)
  * Translate "Default: " and "Remove" in custom fields #12732
    (@krassowski)
  * Fix cell toolbar overlap in side-by-side render mode #12710
    (@peytondmurray)
  * Remove ipywidgets message count in the execution indicator
    model #12665 (@trungleduc)
  Maintenance and upkeep improvements
  * Update verdaccio, start registry on 0.0.0.0 #12825
    (@fcollonval)
  * Use Vega SVG renderer to drop canvas dependency #12811
    (@fcollonval)
  * Bump moment from 2.29.2 to 2.29.4 #12781 (@dependabot[bot])
  * [memory-leaks] Fixes following cell addition analysis #12774
    (@fcollonval)
  * Bump @lumino/widgets to 1.33.0 #12777 (@fcollonval)
  * Fix memory leaks #12750 (@fcollonval)
  * Bump version of marked and @types/marked #12747 (@krassowski)
  * Drop pre-commit from build dependencies (#12680) #12706
    (@jtpio)
- Release 3.4.3
  New features added
  * Persistent side-by-side ratio setting #12633 (@echarles)
  Enhancements made
  * Persistent side-by-side ratio setting #12633 (@echarles)
  * Add "Open in Simple Mode" contextMenu option #12577
  * (@fcollonval)
  Bugs fixed
  * Always check local packages against abspath #10662 (@mlucool)
  * Fix arrow position on unrendered markdown cell #12660
    (@fcollonval)
  * Fix the side-by-side cell resize handle #12611 (@echarles)
  * Fix loading toolbar factory twice #12599 (@fcollonval)
  * Fixes behavior of maxNumberOutputs #12598 (@fcollonval)
  * Focus not set when clicking on cell margin #12447 (@fcollonval)
  * Make selected text translucent so the cursor is visible in vim
    mode #12520 (@Jessie-Newman)
  * Fix file browser search highlighting bug #12578 (@fcollonval)
- Release 3.4.2
  * Building extensions fail if not using latest patch #12571
    (@ajbozarth)
  * fixed shouldOverwrite is never called when rename target exists
    [#12543] (@ephes)
- Release 3.4.1
  Enhancements made
  * Setting to use the advanced setting editor for the settings
  * #12466 (@echarles)
  Bugs fixed
  * Allow users to yarn link @jupyterlab/builder #12533
    (@ajbozarth)
  * Get Auto Close Brackets working consistently in Consoles #12508
    (@Jessie-Newman)
  * Handled new dialog creation with no buttons #12496 (@Jnnamchi)
  * Handle missing preferredPath from the page config #12521
    (@jtpio)
- Release 3.4.0
  Enhancements made
  * Add ability to open settings editor to specific plugin's
    settings #12506 (@fcollonval)
  * Don't sort context menu items by selector #12505 (@fcollonval)
  * Allow downstream extension to set toolbar layout #12503
    (@fcollonval)
  * Display default value in setting editor for changed values
    [#12468] (@echarles)
  * Uses dark theme for Vega when JupyterLab theme is dark #12411
    (@jweill-aws)
  * Creates cell-toolbar, cell-toolbar-extension packages and
    populates toolbar #12028 (@jweill-aws)
  * Customize the file browser toolbar via the settings #12441
    (@fcollonval)
  * Wait until file browser commands are ready before activating
    file browser widget #12435 (@fcollonval)
  * Add a "New Tab" button that opens the launcher #12195
    (@ajbozarth)
  * Simplify galata import by proxying expect #12311 (@fcollonval)
  * Open terminal in cwd from launcher #12250 (@rccern)
  * Add support for filtering by field names in setting editor
    [#12082] (@marthacryan)
  * Use transform to quickly switch between tabs. #11074
    (@fcollonval)
  * Pop up select kernel dialog when run a cell without kernel
    [#12379] (@a3626a)
  * Allow LauncherModel to be more extendable #12344 (@ajbozarth)
  * Add argument searchText and replaceText to search and replace
    commands #12310 (@fcollonval)
  * Add argument line and column to codemirror go to line command
    [#12204] (@fcollonval)
  * Default is no virtual rendering + Relax virtual notebook
    rendering and ensure no structural change until rendering is
    completed #12258 (@echarles)
  Bugs fixed
  * Ensure settings editor is attached before activation #12507
    (@fcollonval)
  * Setting form editor has a formState to avoid focus lost #12470
    (@echarles)
  * Check if process is declared before optional chaining in
    makeSettings #12472 (@fcollonval)
  * Signal should only export ISignal publicly #12471 (@fcollonval)
  * Move cell toolbar below search document widget #12467
    (@fcollonval)
  * Use css variable for font size. #12255 (@Carreau)
- More release notes for 3.3.0 and older:
  * https://github.com/jupyterlab/jupyterlab/releases and
    ChANGELOG.md
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Allow to keep the config in %%_distconfdir
* Fri Nov 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.2.3
  * [3.2.x] Expose window.jupyterapp #11417 (@jtpio)
  * Handle relative paths to themePath and schemaDir #11427
    (@jtpio)
  * fix #11377 & bump Yjs dependencies & fix modeldb overwriting
    yjs content
  * akes ILabShell optional in toc extension
- Changes in 3.2.2
  * Make orig_nbformat optional #11005 #11370 (@nanoant)
  * Updated dialog with text to a reasonable width #11331 (@3coins)
  * Fix for terminal theme style #11291 (@3coins)
  * Only trigger dirty status update on value changes #11346
    (@krassowski)
  * Run nested code cells directly from markdown headings #11375
    (@jess-x)
  * Fix release_test #11390 (@fcollonval)
  * Removed cat package.json #11372 (@ceesu)
  * Relax @playright/test dependency in Galata #11371 (@jtpio)
- Changes in 3.2.1
  * Updated button styles to accessible colors #11321 (@3coins)
  * Fix for debugger not working for scripts #11311 (@3coins)
  * Added handling of '\r' ended files #11310 (@lucabarcelos)
  * Emit indexChanged on model state updates #11298 (@krassowski)
  * Fix ANSI vs URL conflict, prefix www. with https:// #11272
    (@krassowski)
  * Pass version spec as an input #11322 (@jtpio)
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.2.0
  Enhancements made
  * Add a menu entry to show/hide hidden files in the filebrowser
    [#11206] (@loichuder)
  * Restore Copy shareable link use of shareUrl #11188
    (@fcollonval)
  * Add Galata in JupyterLab #11179 (@fcollonval)
  * Responsive Toolbar #11178 (@3coins)
  * Make check margin between last modified timestamps on disk and
    client configurable #11153 (@ph-ph)
  * Reuse cell id of cut cell on cut + paste #11138 (@smacke)
  * Add Side-by-side Rendering #11143 (@blink1073)
  * Add show trailing whitespace option to Notebook and Text Editor
    [#11131] (@blink1073)
  * Implement Restart and debug #11129 (@blink1073)
  * Add preferred-dir handling #10667 (@goanpeca)
  * Enable disabling document-wide history tracking #10949
    (@echarles)
  * Removed debug switch #11185 (@3coins)
  Bugs fixed
  * Normalize cell source \r line endings #11271 (@jasongrout)
  * Fix Webpack crypto handling #11249 (@blink1073)
  * Use standard hash type in webpack build #11234 (@blink1073)
  * Remove format from fetching options if null #11229 (@loichuder)
  * Do not continuously cd('/') when already in / #11219 (@minrk)
  * Properly reset layout when toggling simple mode. #11203
    (@jasongrout)
  * Fix renaming issue in collaborative mode #11197 (@dmonad)
  * Restore workspace and open tree path #11176 (@blink1073)
  * Share notebook's metadata #11064 (@hbcarlos)
  * Normalize notebook cell line endings to \n #11141 (@jasongrout)
  * Fix auto close brackets for console #11137 (@ohrely)
  * Add a guard to avoid kernel deadlock on multiple input request
    [#10792] (@echarles)
  Maintenance and upkeep improvements
  * Extension upgrade script: Avoid throwing exceptions for certain
    package.json files #11278 (@ammgws)
  * Run Linter #11238 (@blink1073)
  * Fix Release Check #11218 (@fcollonval)
  * Handle case when JupyterHub returns 424 for not running server
    [#11205] (@yuvipanda)
  * Check i18n will pass on zeroed patch pre-release version #11214
    (@fcollonval)
  * Refactor window.open to make it work also in desktop app #11202
    (@mbektas)
  * Rename "JupyterLab Theme" to "Theme" #11198 (@jtpio)
  * Use only context and id to check i18n #11190 (@fcollonval)
  * Fix the "Edit on GitHub" link #11149 (@krassowski)
  * Clean up notebook test utils #11133 (@blink1073)
  * Change "Export Notebook As" to "Save and Export Notebook As"
    [#11132] (@blink1073)
  * Make Test Server Configurable #11015 (@fcollonval)
  * Use disableDocumentWideUndoRedo instead of
    enableDocumentWideUndoRedo #11215 (@echarles)
  * Fix kernelspec logo handling (#11175) #11183 (@jtpio)
  Documentation improvements
  * Fix typo in docs: page_config.json
    [#11152]https://github.com/jupyterlab/jupyterlab/pull/11152)
    (@achimgaedke)
  * Add a menu entry to show/hide hidden files in the filebrowser
    [#11206] (@loichuder)
  * Fix the "Edit on GitHub" link #11149 (@krassowski)
  * Clarify sidebar switching settings #11270 (@joelostblom)
- Release 3.1.17
  Bugs fixed
  * Use standard hash type in webpack build #11234 (@blink1073)
- Release 3.1.16
  Bugs fixed
  * Do not continuously cd('/') when already in / #11219 (@minrk)
  * Properly reset layout when toggling simple mode. #11203
    (@jasongrout)
  * Fix renaming issue in collaborative mode #11197 (@dmonad)
  * Restore workspace and open tree path #11177 (@blink1073)
  * Share notebook's metadata #11064 (@hbcarlos)
  Maintenance and upkeep improvements
  * Check i18n will pass on zeroed patch pre-release version #11214
    (@fcollonval)
  * Fix Release Check #11218 (@fcollonval)
  * Handle case when JupyterHub returns 424 for not running server
    [#11205] (@yuvipanda)
  * Use only context and id to check i18n #11190 (@fcollonval)
- Release 3.1.14
  Bugs fixed
  * Normalize notebook cell line endings to \n #11141 (@jasongrout)
  Maintenance and upkeep improvements
  * Fix the "Edit on GitHub" link #11149 (@krassowski)
  Documentation improvements
  * Fix the "Edit on GitHub" link #11149 (@krassowski)
- Release 3.1.13
  Enhancements made
  * Fetch translations via the ServerConnection.ISettings #11091
    (@jtpio)
  Bugs fixed
  * Update the lock after every request #11092 (@hbcarlos)
  * use posix explicitly for PathExt #11099 (@mbektas)
  * Backport PR #10868 on branch 3.1.x (Fix user preferences not
    being considered for Text Editor) #11087 (@Mithil467)
  * Indent comments (#6957) #11063 (@josephrocca)
  Maintenance and upkeep improvements
  * Check changes on translatable strings #11036 (@fcollonval)
  * Skip flaky debugger test #11083 (@fcollonval)
  Documentation improvements
  * Add a note on the Jupyter Releaser in the extension tutorial
    [#11085] (@jtpio)
  Other merged PRs
  * Remove item from changelog that slips through #11110
    (@fcollonval)
* Sun Sep 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.1.12
  * Retain the rtc lock until the user releases it #11026
    (@hbcarlos)
  * Backport PR #11031 on branch 3.1.x (Use posix paths explicitly)
    [#11045] (@Mithil467)
  * Adds the variable reference to the key of the component #11029
    (@hbcarlos)
  * Clean up bumpversion #11056 (@blink1073)
  * Make debugger jest test more robust #11032 (@fcollonval)
  * Remove status bar item flickering #11065 (@fcollonval)
  * use path.posix explicitly for URLs #11048 (@mbektas)
* Tue Sep 14 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.1.11
  * Full Changelog at
    https://jupyterlab.readthedocs.io/en/stable/getting_started/changelog.html
- Fix rpmlint 2 filter for required .orig files
* Mon Aug 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.1.7
  * Full Changelog at
    https://jupyterlab.readthedocs.io/en/stable/getting_started/changelog.html
- Notable change in version 3.1
  * From JupyterLab 3.1, file documents and notebooks have
    collaborative editing using the Yjs shared editing framework
    Editors are not collaborative by default; to activate it, start
    JupyterLab with the --collaborative flag. See full
    documentation on collaboration:
    https://jupyterlab.readthedocs.io/en/latest/user/rtc.html
* Tue Feb  9 2021 Jan Engelhardt <jengelh@inai.de>
- Set buildshell to /bin/bash for use of "+=".
* Thu Feb  4 2021 Benjamin Greiner <code@bnavigator.de>
- Fix typo in requirements
* Tue Feb  2 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.0.7
  * Full Changelog at
    https://jupyterlab.readthedocs.io/en/stable/getting_started/changelog.html
- User Facing changes in v3.0.0
  * Extensions can be installed without building JupyterLab with
    NodeJS
  * The JupyterLab interface supports multiple language
  * A new visual debugger
  * Improvements to Simple Interface mode and Mobile
  * Table of Contents is now in core
  * Visual filter in file browser
  * Property inspector moved to right sidebar
  * Command Palette is a floating window
  * Now depends on Jupyter Server
* Thu Jul 16 2020 Todd R <toddrme2178@gmail.com>
- Update to 2.2.0
  + User-facing changes
  * Cells can no longer be executed while kernels are terminating or restarting. There is a new status for these events on the Kernel Indicator
  * Adds a visual clue for distinguishing hidden files and folders in the file browser window
  * Enable horizontal scrolling for toolbars to improve mobile experience
  * Improves the right-click context menu for the file editor
  * Merge cell attachments when merging cells
  * Add styling for high memory usage warning in status bar with nbresuse
  * Adds support for Python version 3.10
  * Support live editing of SVG with updating rendering
  + For developers
  * Specify that we recommend typescript over javascript for extensions
  * Lazy load codemirror theme stylesheets.
  * Increase the link expiry to one week
  * Add documentation on private npm registry usage
  * Add feature request template + slight reorg in readme
  * Add link to react example in extension-examples repo
  * Update documentation of whitelist/blacklist
  * Improve whitelist figure description in documentation
  + Bugfixes
  * Typo: fix extensino to extension
  * Close correct tab with close tab
  * Remove unused css rules
  * Fix small typo in getting started docs, proxy
  * Fix link on CI badges
  * Simplified multicursor backspace code
  * Fix recent breaking changes to normalizepath in filebrowser
  * Fix watch mode and add ci test
  * Address CI failures
  * Fix lint errors in dependency graph script
  * Fix lint complaints coming up from github actions
  * Address CI usage test timeout
  * Add chokidar to dev_mode/package.json
  * Fix autolink
  * Update phosphor aliases
  * Fix default return in Python when extension has no version metadata
  * Updated the installation documentation on read the docs to match the readme file on the repo
  * Handle quit_button when launched as an extension
  * Add worker-loader
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.4:
  * Various minor fixes
* Sun May 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix download url
- Fix the deps to match setup.py
* Sat May 23 2020 Arun Persaud <arun@gmx.de>
- update to version 2.1.3:
  * Fix Jupyterlab manager extension handling of missing package
    metadata (#8463)
  * Python 3.10 compatibility (#8446)
  * Fix extension compatibility checks (#8434)
- changes from version 2.1.2:
  * Fix icon sidebar height for third party extensions (#8333)
  * Pin JupyterLab server requirement more tightly (#8330)
  * Scrolls cells into view after deletion (#8287)
  * Sets data attribute on file type in filebrowser (#8275)
* Sat Apr 25 2020 Arun Persaud <arun@gmx.de>
- update to version 2.1.1:
  * Pin puppeteer to fix ci (#8260)
  * Fix Save As for files without sessions (#8248)
  * fix sed commands for /usr/bin/env
- changes from version 2.1.0:
  * See the JupyterLab 2.1 milestone on GitHub for the full list of
    pull requests and issues closed.
  * User-facing changes
    + Display the extension manager in the left sidebar by
    default. Users will need to acknowledge the disclaimer in the
    extension manager before using it. (#8050, #8145)
    + Added blacklist and whitelist support for the extension manager
    (#7989)
    + Automatically link URLs in notebook output text (#8075, #7393)
    + Added a “Restart Kernel and Run All Cells…” button to the
    notebook toolbar (#8024)
    + Added a context menu item for opening a Markdown editor from the
    Markdown preview (#7942)
    + Support Node.js 10+ (#8112, #8083)
    + Added a command to replace the selection in an editor with text
    (inserting if there is no selection). This can be assigned a
    keyboard shortcut, as shown below. We also added a command to go
    through a series of commands and run the first enabled
    command. (#7908)
  * For developers
    + NotebookWidgetFactory is now a plugin so it can be overridden
    (#8066, #7996)
    + Many improvements to LabIcon: work with all SVG loaders, improve
    performance, fix issue with menus from extensions (#8125)
    + Change the header application area to a box panel, which means
    the header area will display if its children set their minimum
    height (#8059, #7279)
    + JupyterLab’s custom context menu is now disabled on all
    descendants of a DOM element with a
    data-jp-suppress-context-menu attribute (#7877, #7670)
  * Bugfixes
    + Fix property inspector restoration on reload (#8114)
    + Increase the timeout for yarn (#8104, #8102)
    + Fix find and replace with empty strings (#8100, #8098)
    + Select search text when focusing the search overlay (#8073,
    [#7932])
    + Fix attaching images with spaces in their names to Markdown
    cells (#8095)
    + Fix build errors by distributing the .yarnrc configuration with
    the Python package (#8045)
    + Throttle fetch requests in the setting registry’s data connector
    (#7927)
    + Close the gap between lines in notebook output (#7832, #7760)
- changes from version 2.0.2:
  * Fix cell execution when recording timing (#8057, #8056)
  * Fix font settings for the editor (#8004, #7910)
  * Avoid redundant checkpoint calls on loading a notebook (#7926,
    [#7889])
  * For developers: make kernel IFuture.done typings more correct by
    not including undefined (#8032)
* Wed Apr  1 2020 Tomáš Chvátal <tchvatal@suse.com>
- We should work with tornado 4, 5 and 6.
- The bugs were found in tornado 6.0.1 and 6.0.2 were fixed
  by upstream developers
* Fri Mar  6 2020 Todd R <toddrme2178@gmail.com>
- Requires nodejs/npm >= 10
* Tue Mar  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 2.0.0
  + User-facing changes
  * New user interface for notebook cell tags
  * File info display when hovering on a file in the file browser
  * Support for searching outputs in notebooks
  * ``Ctrl Shift .`` and ``Ctrl Shift ,`` shortcuts move focus to the next and previous tab bar in the main area, respectively
  * ``Shift Home`` and ``Shift End`` shortcuts in a notebook select all cells from the current cell to the top or bottom of a notebook, respectively
  * Explicit "No Kernel" button in the kernel selection dialog for new notebooks
  * Notebook ``recordTiming`` advanced setting to control whether execution timing information is stored in notebook files
  * "Select current running or last run cell" command added (requires notebook ``recordTiming`` advanced setting to be set to true)
  * Codemirror ``lineWiseCopyCut`` advanced setting to control the behavior of the copy/cut keyboard shortcuts when there is no selection
  * Refreshed the command palette and property inspector sidebar icons and user interfaces
  * "New File" and "New Markdown File" items in file browser context menu
  * "Download" item in File menu
  * "Restart Kernel and Run up to Selected Cell" item in notebook Kernel menu
  * In extension manager, the "enable" button is now only shown for installed extensions
  * Dialogs can now be closed by clicking outside of them
  * ``documentsearch:startWithReplace`` command to open the document find overlay with replace. There is not currently a default keyboard shortcut for this, but one can be assigned as a custom keyboard shortcut in Advanced Settings.
  * ``#`` added to the CSV Viewer delimiter options
  * The JSON viewer now only displays structure hints for arrays and empty objects for a more streamlined feel
  * Optional platform-aware keyboard shortcut fields ``linuxKeys``, ``macKeys``, and ``winKeys`` in keyboard shortcut definitions
  * Added options for ``jupyter lab clean`` to clean specific parts of the build, such as ``--extensions``, ``--settings``, ``--static``, and ``--all``
  * Removed the vega 4 and vega-lite 2 renderers (vega 5 and vega-lite 4 is included in JupyterLab by default). These legacy renderers may be available via custom extensions
  * JupyterHub users should use the ``c.Spawner.default_url = '/lab'`` setting instead of the deprecated and now removed ``labhubapp``
  + Backward incompatible changes
  * Switch from ``@phosphor`` to ``@lumino`` dependencies.
  * Factor out the ``settingsregistry`` and ``statedb`` packages from coreutils
  * Rework services architecture (sessions, kernels, terminals) and rename ``ClientSession`` to ``SessionContext``
  * Upgrade to TypeScript 3.7
  * Remove ``polling`` from coreutils in favor for ``@lumino/polling``
  * TypeScript strict null checking in core packages
  * Update state database list method to query based on namespace match.
  * Address code todo items and deprecations for 2.0
  * Update Console panel tracker widgets
  * Update contribution guide to require node v12+
  * New API for the ``Running`` sidebar extension
  * Clean up handling of icons under unified LabIcon
  + Other changes
  * New property inspector used to display the properties of the currently selected main area widget
  * Allow metadata for launcher items
  * Allow default file browser to restore manually.
  * Upgrade bundled yarn to 1.21.1
  * Make session dialogs configurable
  * Support transient editor configs
  * Optionally force new browser tab
  * Update core dependencies (e.g., ``codemirror``, ``xterm.js``, ``markdown``, ``fontawesome``, etc.)
  * Add storybook to ``ui-components``
  * Add explicit documentation encouraging people to re-use lab components
  * Enable TypeScript sourcemaps for debugging locally installed labextensions
  * Add ``UseSignal`` example to the docs
  * Add ``env`` prop to kernel options
  * Add kernelspec metadata
  * Allow different mimetypes for the clipboard data
  * Add password dialog to apputils
  * Alias phosphor packages to lumino to allow a deprecation period for phosphor
  * Match react version in ui-components peerdependencies
  * Fix lint-staged for both win and mac
  * Update websocket workaround for node environments
  * Fix handling of linked extensions
  * Fix extension compatibility checks for prereleases and extensions supporting multiple major versions of JupyterLab
  * Teach update-dependency about more range specifiers and make it adopt the current range for any tag
  * Add support for giving a rank to items in the top area
  * Apply all options to the initial JupyterLab application instance
  + Bugfixes
  * "Copy Shareable Link" in the file browser context menu now properly works in JupyterHub
  * Update Mathjax CDN in the cell and console examples
  * Revert ensure-max-old-space now that Node 12+ has better default memory ceilings
  * Resolve race condition between default file browser and tree urls.
  * Fix handling of code editor refresh
  * Start new notebooks in edit mode
  * Use consistent versions of React
  * Add scrollbar styles to nbconvert-css
  * Close output views when corresponding notebooks are closed
  * Fixed incorrect white background for new command palette icon
  * Block fetching the settings for a plugin that is disabled
  * When timing metadata changes, ensure signal fires
  * Prevent memory leaks in Vega renderer
  * Handle cell execution cancellation when cell is disposed
  * Fix dropdown option style issue on Windows
  * Make sure label is linked to a control when checking for element type
  * Refine log console message UX
  * Fix multicursor backspacing
  * Reset log display and count when non-notebook tab gets activated
  * Fix Safari multiple tabs by working around a Safari bug.
  * Skip custom click behavior on links when the download attribute is set
  * Fix context menu hit test to deal with SVG nodes.
  * Fix overwriting of target attribute of anchors rendered by ``IPython.display``
  * Fix file browser location in tree view
  * Stop too many fetch calls in docmanager-extension
  * Ensures that ``Shift Tab`` dedent shortcut works correctly in the file editor
  * Fix unexpected jump to last search result when using documentsearch
  * Fixed refresh issue for html viewer
  * Fix for center-aligned images with IPython.display.image
  * Changes to setting editor should trigger application dirty state
  * Move vega from "devdependencies" to "dependencies"
  * Restore default file browser manually.
  * Use default ``app_dir`` when ``app_dir`` is ``''``
* Tue Jan 28 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.2.6
  * Update dependencies
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.2.4
  * update yarn.lock
  * update terser dep
* Tue Dec 10 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use pyproject_install macro (boo#1094323)
* Mon Dec  9 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.2.3
  * Update status bar index.css to be hand-curated
  * fix dropdown option style issue in Windows
  * Update the ui-components css to reflect the correct dependencies.
- Rename spec file to python-jupyterlab to work better
  with OSC python tooling.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.2.2
  + User-facing changes
  * Select cells from the current cell to the top of the notebook with ``Shift Home``, to the bottom of the notebook with ``Shift End``
  * Add a log console extension to display unhandled messages and other activity
  * Allow the npm ``max-old-space`` option to be specified outside of JupyterLab
  * Only display node structure in a JSON tree view for arrays and empty objects
  * Make much smaller distribution packages by not building JavaScript source maps for releases.
  * Add support for pasting cell attachments and dragging attachments from the file browser
  * Add a new ``registry`` configuration parameter to override the default yarn repository when building
  + For developers
  * Update the Markdown renderer (``marked``) to 0.7.0
  * Remove datagrid as a singleton, allowing extensions to use newer versions
  * Add metadata to the kernelspec information
  * Allow different mimetypes for the clipboard data
  * Add inline svg icon support to toolbar buttons
  * Add PageConfig functions to query if a plugin is deferred or disabled
  * Allow for renderers for nbformat.ierror to be created
  * Refactor ``fileeditor-extension`` for modularization
  * Add execution timing to cells
  + Bugfixes
  * Fix the ``file-browser-path`` query parameter
  * Skip custom click behavior on links when the download attribute is set
  * Fix opening multiple browser tabs in Safari
  * Fix context menus on SVG icons
  * Fix overwriting of target attribute of anchors rendered by ``IPython.display``
  * Fix multi-cursor backspacing
  * Fix mult-cursor cell splitting
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Use better way to handle tornado version compatibility.
* Fri Aug 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.9
  * integrity
  * update packages
  * fix package name
  * enforce jinja2 requirement
- jupyterlab-discovery has been merged into jupyterlab
* Tue Aug 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.6
  + User Facing Changes
  * We have added first class support for find and replace across JupyterLab. It is currently supported in notebooks and text files and is extensible for other widgets who wish to support it.
  * We have integrated the JupyterLab Status Bar package into the core distribution. Extensions can add their own status to it as well.
  * We now include the JupyterHub extension in core JupyterLab, so you no longer need to install ``@jupyterlab/hub-extension``.
  * JupyterLab now has a File > Logout menu entry when running with JupyterHub
  * now have a printing system that allows extensions to customize how documents and activities are printed.
  * The launcher displays longer kernel names and supports keyboard navigation
  * Notebook outputs without any valid MimeType renderers will not be displayed, instead of displaying an error
  * Add tooltip to file browser root breadcrumb icon showing the server root, if it is available
  * Downloading a file will no longer open a new browser window
  * Rename the help "Inspector" to "Contextual Help" and move it to the "Help" menu
  * Update many of the icons to make them more consistent
  * Update the settings UI to remove the table view
  * Replace FAQ Extension with link to JupyterLab documentation
  * Change the default keyboard shortcut for closing a tab to be ``Alt+w`` instead of ``Cmd/Ctrl+w`` to avoid conflicts with operating systems.
  * Show help text in Inspector window to describe you should select a function
  * Fixes SVG rendering
  * Add support for dropping a tab in the tab bar area.
  * Switch some default shortcuts to use ``Accel`` instead of ``Ctrl`` so they are more natural for Mac users
  * Add ability to tell between hover and selected command palette items
  * Hide the "Last Modified" column when the file browser is narrow
  * Support copy/paste in terminal and Mac OS using ``Ctrl+C`` and ``Ctrl+V``
  * Support scrolling in running kernels panel
  * Adds ability to "Merge Selected Cells" in the context menu in the notebook
  * Turn On Accessibility In Xterm.js to make it more compatible for screen readers
  * When selecting cells using the keyboard shortcuts, we now skip collapsed cells
  * Supporting opening ``.geojson`` files in JSON viewer
  * Performance fixes for text-based progress bars
  * Add support for rendering Vega 5 and Vega Lite 3 while keeping the existing Vega 4 and Vega Lite 2 renderers
  * Drag and drop console cells into a notebook or text editor
  * Drag and drop notebook cells into a console or text editor
  * The extension manager search now sorts extensions by the score assigned to them by NPM instead of alphabetically
  * Notify the user when a kernel is automatically restarted, for example, if crashes from an out of memory error
  * Expose the extension manager in a command and menu item
  * Add command to render all Markdown cells
  * Supports using shift to select text in output area
  * Output areas that opened in new views are restored properly now on reload
  * Add support for managing notebook metadata under a new "Advanced Tools" section in the cell tools area. The cell and notebook metadata now always reflect the current state of the notebook
  * Inherit terminal theme from core theme
  * Adds a built-in HTML viewer so that you can view HTML files
  * New workspaces are now automatically generated when you create a new window with the same workspace name.
  * We now add a hint to the context menu to describe how you can access the native browser menu
  * The tabs on the left panel have changed to make them more understandable
  * Start a new terminal when the page is refreshed and the old terminal has died
  * Add a command to open the main menus, which can be assigned to a keyboard shortcut to open and navigate menus without a mouse
  * The contextual help now updates based on changes in the cursor from the mouse instead of just from the keyboard
  * The launcher now updates when the kernels change on the server
  * Retain cell auto scroll behavior even when a cell output is cleared
  * If you link to a relative path that is not a file in a markdown cell, this will now be preserved instead of changing it to a file URL
  * Adds the ability to link to a certain row in a CSV file and have the viewer open to that row
  * We have improved the performance of switching to a large notebook
  * The vdom extension now supports event handling, so that you can have kernel code run in response to user interaction with the UI
  * Adds the ability to run "Run All Code" and "Restart Kernel and Run All Code" in code and markdown files
  * We now remember what line ending a text file has when loading it, so that files with ``CRLF`` line endings will properly be saved with the same endings
  * Fixes rendering of SVG elements in HTML MimeType output
  * Allow copying files by holding down ``Ctrl`` when dragging them in the file browser
  * Switch the hover modified time in the file browser to use the local format
  * We have added a default keyboard shortcut of ``Ctrl Shift Q`` for closing and cleaning up a file
  * Adds the ability to find and go to a certain line in the CSV viewer
  * Add the ability to create new text and markdown files from the launcher and command palette
  * A "New Folder" option has been added to the file browser context menu
  * The ANSI colors are now the same as those in the classic notebook
  * Send complete statements instead of current lines when stepping through code in a cell
  * Description list styles (``dl``, ``dt``, ``dd``) are improved to be consistent with the nteract project
  + Settings
  * The settings system has been rewritten and now uses json5 as the syntax, which supports comments and other features for better human readability.
  * The keyboard shortcut system has been rewritten and now displays a list of system commands in the settings comments.
  * There are new settings for many following items, including:
    > Adds an option to shut down terminals and notebook kernels when they are closed
    > Scrolling past the end of a notebooks and text editor document
    > Text editor code folding, rulers, and active line highlighting
    > Markdown viewer options
    > Terminal scrollback and other settings
    > The autosave interval
    > The file browser showing the current active file
    > Custom scrollbar styling for dark themes
  + Command Line Changes
  * Installing extensions will be quieter and adds a ``--debug`` to extension installing
  * We now support running JupyterLab when its application directory is a symlink
  * Add ``--all`` flag to ``labextension uninstall`` to remove all extensions
  * Adds the ability to override the base URLs from the config
  * Updates to workspaces CLI command
  + Extension Development Changes
  * We have rewritten how extensions provide keyboard shortcuts and interact with the settings system. If you previously defined keyboard shortcuts or used the settings mechanism, you will need to update your extension
  * We have renamed the plugin type from ``JupyterLabPlugin`` to ``JupyterFrontEndPlugin``. The application arg is also renamed from ``JupyterLab`` to  ``JupyterFrontEnd`` and some its functionality has been moved to a separate ``ILabShell`` plugin
  * The lab shell ``addToMainArea``, ``addToLeftArea``, ``addToTopArea``, ``addToRightArea``, and ``addToBottomArea`` functions have been replaced with a single ``add()`` function that takes the area as an argument. Replace ``addToMainArea(widget, options)`` with ``add(widget, 'main', options)``, etc.
  * Rename ``pageUrl`` to ``appUrl`` in the server connection
  * ``MainAreaWidget`` instances now forward update requests to their ``content``
  * The theme data attributes are renamed and moved to the document body element. If you are relying on these attributes in CSS to conditionally style based on the theme, you should update their names. For example ``data-theme-light`` is now ``data-jp-theme-light``.
  * Extensions which require CSS should no longer import their CSS files into their Javascript files. Instead, they should specify a root CSS file in the ``style`` attribute in their ``package.json``, and JupyterLab will automatically import that CSS file.
  * ``Dialog.prompt`` has been replaced by a number of type-specific dialogs such as ``InputDialog.getString``, ``InputDialog.getBoolean``, etc.
  * When a ``RenderMime`` widget is re-rendered, the default behavior is to remove any existing content in the DOM. This can be overridden if needed.
  * We have updated our internal TypeScript version to 3.5.1 and our compile target to ``ES2017``. Extensions may need to upgrade their TypeScript version and target as well.
  * We have updated the typings for some of the Kernel messages so that they better match the spec.
  * A ``connectionFailure`` signal has been added to some of the manager classes, which can be used to detect when a connection to the server is lost
  * Add rate limiting and polling utilities to ``coreutils``  to use for throttling and debouncing of API requests
  * Require session when instantiating terminal widget
  * Provides a signal to see what items are opened in a directory listing
  * Ads the ability to add widget above the main work area to a top header area
  * Renames ``contextMenuFirst`` to  ``contextMenuHitTest`` in the ``JupyterFrontEnd``
  * Removes the ``initialCommand`` arg from the terminal creation command.
  * Adds ``--jp-code-cursor-width0``, ``--jp-code-cursor-width1``, and ``--jp-code-cursor-width2`` variables to the themes to support changing the cursor width if you change the font size
  * Adds the ability to insert a new item to the toolbar before or after another item
  * Adds the ability for extensions to register new CodeMirror modes
  * We have removed the ``JUPYTERLAB_xxx_LOADER`` Webpack loaders, instead you should use the loader directly in the URL as Webpack supports it
  * Adds the ability to handle fragments for document widgets
  * We have added a  ``@jupyterlab/ui-components`` package that contains reusable React components to be used internally and in extensions. Feel free to use this to create extension UIs with consistent styles
  * The ``showErrorMessage`` function now lets you customize the buttons it uses
  * We now provide helpers for using React components within JupyterLab. If you were previously using ``ReactElementWidget`` you should switch to using ``ReactWidget``.
  * The share link command has been moved to its own extension so that it can be overridden
  * Creating a new services session now requires passing a kernel model instead of a kernel instance
  * We upgraded the Webpack raw file loader. The new version of the raw loader exports ES2015 modules, so this may require changes in extensions that import files using the raw loader. For example, if you did ``require('myfile.md')`` to get the content of `myfile.md` as a string, you now should import it using ES2015 `import` syntax, or use `require('myfile.md').default`.
  * Widget factories now can support custom cloning behavior from an optional source widget
  * We have renamed the type ``InstanceTracker`` to ``WidgetTracker``.
  * In order to add widgets to the main area (e.g. as in the old XKCD extension tutorial), the correct syntax is now ``app.shell.add(widget)`` or ``app.shell.add(widget, 'main')``,
* Tue May 14 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.6
  * Publish outputarea 0.19.2
  * Make sure the cached value of `_lastStream` reflects the removed
    characters so we don't have to remove them over and over again.
- Split directories and macros into separate package.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.5
  * use target=_blank for download links
  * Release filebrowser@0.19.4
- Rename to to match jupyter package naming guidelines.
- Add rpm macros
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.35.4
  + Features
  * A notebook cell can now be readonly, reflecting its ``enabled`` metadata. (`#5401 <https://github.com/jupyterlab/jupyterlab/pull/5401>`__, `#1312 <https://github.com/jupyterlab/jupyterlab/issues/1312>`__)
  * Add "Go To Line" in the Edit menu for text editors. (`#5377 <https://github.com/jupyterlab/jupyterlab/pull/5377>`__)
  * Sidebar panels can now be switched between left and right sidebars. Right-click on a sidebar tab to move it to the other sidebar. (`#5347 <https://github.com/jupyterlab/jupyterlab/pull/5347>`__, `#5054 <https://github.com/jupyterlab/jupyterlab/  issues/5054>`__, `#3707 <https://github.com/jupyterlab/jupyterlab/issues/3707>`__)
  * Make the sidebar a bit narrower, and make the minimum width adjustable from a theme. (`#5245 <https://github.com/jupyterlab/jupyterlab/pull/5245>`__)
  * Populate the File, Export Notebook As... submenu from the server nbconvert capabilities. (`#5217 <https://github.com/jupyterlab/jupyterlab/pull/5217>`__)
  * Server contents managers can now tell JupyterLab to open files as notebooks. For example, several custom contents managers save and open notebooks as Markdown files. (`#5247 <https://github.com/jupyterlab/jupyterlab/pull/5247>`__, `#4924 <https://github.com/jupyterlab/jupyterlab/issues/4924>`__)
  * Add a command-line interface for managing workspaces. (`#5166 <https://github.com/jupyterlab/jupyterlab/pull/5166>`__)
  * Allow safe inline CSS styles in Markdown. (`#5012 <https://github.com/jupyterlab/jupyterlab/pull/5012>`__, `#1812 <https://github.com/jupyterlab/jupyterlab/issues/1812>`__)
  * Add Quit to File menu when appropriate. (`#5226 <https://github.com/jupyterlab/jupyterlab/pull/5226>`__, `#5252 <https://github.com/jupyterlab/jupyterlab/pull/5252>`__, `#5246 <https://github.com/jupyterlab/jupyterlab/issues/5246>`__, `#5280 <https://github.com/jupyterlab/jupyterlab/pull/5280>`__)
  * Rework extension manager user experience. (`#5147 <https://github.com/jupyterlab/jupyterlab/pull/5147>`__, `#5042 <https://github.com/jupyterlab/jupyterlab/issues/5042>`__)
  + Dark theme
  * Show a dark splash screen when using a dark theme. (`#5339 <https://github.com/jupyterlab/jupyterlab/pull/5339>`__, `#5338 <https://github.com/jupyterlab/jupyterlab/issues/5338>`__, `#5403 <https://github.com/jupyterlab/jupyterlab/pull/5403>`__)
  * Fix code completion menu for a dark theme. (`#5364 <https://github.com/jupyterlab/jupyterlab/pull/5364>`__, `#5349 <https://github.com/jupyterlab/jupyterlab/issues/5349>`__)
  * Style CSV viewer for a dark theme. (`#5304 <https://github.com/jupyterlab/jupyterlab/pull/5304>`__, `#3456 <https://github.com/jupyterlab/jupyterlab/issues/3456>`__)
  * Make Matplotlib figures legible in a dark theme. (`#5232 <https://github.com/jupyterlab/jupyterlab/pull/5232>`__)
  * Fix notebook cell dropdown legibility in a dark theme. (`#5168 <https://github.com/jupyterlab/jupyterlab/issues/5168>`__)
  + Bug fixes
  * Various save options in the file menu and toolbar are now disabled when a file is not writable. (`#5376 <https://github.com/jupyterlab/jupyterlab/pull/5376>`__, `#5391 <https://github.com/jupyterlab/jupyterlab/pull/5391>`__)
  * Kernel selector dialog no longer cuts off kernel names. (`#5260 <https://github.com/jupyterlab/jupyterlab/pull/5260>`__, `#5181 <https://github.com/jupyterlab/jupyterlab/issues/5181>`__)
  * Fix focus issues with the toolbar. (`#5344 <https://github.com/jupyterlab/jupyterlab/pull/5344>`__, `#5324 <https://github.com/jupyterlab/jupyterlab/pull/5324>`__, `#2995 <https://github.com/jupyterlab/jupyterlab/issues/2995>`__, `#5328 <https://github.com/jupyterlab/jupyterlab/pull/5328>`__)
  * Fix toolbar button enabled/disabled status. (`#5278 <https://github.com/jupyterlab/jupyterlab/pull/5278>`__)
  * Table alignment is now respected in Markdown. (`#5301 <https://github.com/jupyterlab/jupyterlab/pull/5301>`__, `#3180 <https://github.com/jupyterlab/jupyterlab/issues/3180>`__)
  * Fix syntax highlighting for Markdown lists. (`#5297 <https://github.com/jupyterlab/jupyterlab/pull/5297>`__, `#2741 <https://github.com/jupyterlab/jupyterlab/issues/2741>`__)
  * Use the current filebrowser instead of the default one for various commands. (`#5390 <https://github.com/jupyterlab/jupyterlab/pull/5390>`__)
  * Fix escaping in link handling to conform to Markdown syntax. This means that spaces in link references now need to be encoded as ``%%20``. (`#5383 <https://github.com/jupyterlab/jupyterlab/pull/5383>`__, `#5340 <https://github.com/jupyterlab/jupyterlab/pull/5340>`__, `#5153 <https://github.com/jupyterlab/jupyterlab/issues/5153>`__)
  + Build system
  * Use Typescript 3.1. (`#5360 <https://github.com/jupyterlab/jupyterlab/pull/5360>`__)
  * Use Lerna 3.2.1. (`#5262 <https://github.com/jupyterlab/jupyterlab/pull/5262>`__)
  * Node >=6.11.5 is now required. (`#5227 <https://github.com/jupyterlab/jupyterlab/pull/5227>`__)
  * Pin vega-embed version to 3.18.2. (`#5342 <https://github.com/jupyterlab/jupyterlab/pull/5342>`__)
  * Use Jest for services tests. (`#5251 <https://github.com/jupyterlab/jupyterlab/pull/5251>`__, `#5282 <https://github.com/jupyterlab/jupyterlab/pull/5282>`__)
  * Make it easier for third party extensions to use the JupyterLab test app and testing utilities. (`#5415 <https://github.com/jupyterlab/jupyterlab/pull/5415>`__)
  * Fix ``jupyter lab clean`` on Windows. (`#5400 <https://github.com/jupyterlab/jupyterlab/pull/5400>`__, `#5397 <https://github.com/jupyterlab/jupyterlab/issues/5397>`__)
  * Fix ``jupyter lab build`` on NFS. (`#5237 <https://github.com/jupyterlab/jupyterlab/pull/5237>`__, `#5233 <https://github.com/jupyterlab/jupyterlab/issues/5233>`__)
  * Build wheels for Python 3 only. (`#5287 <https://github.com/jupyterlab/jupyterlab/pull/5287>`__)
  * Migrate to using ``jupyterlab_server`` instead of ``jupyterlab_launcher`` and fix the app example. (`#5316 <https://github.com/jupyterlab/jupyterlab/pull/5316>`__)
  * Move Mathjax 2 typesetter to a library package. (`#5259 <https://github.com/jupyterlab/jupyterlab/pull/5259>`__, `#5257 <https://github.com/jupyterlab/jupyterlab/issues/5257>`__)
  + For Developers
  * Default toolbar buttons can be overridden, and mime renderers can now specify toolbar buttons. (`#5398 <https://github.com/jupyterlab/jupyterlab/pull/5398>`__, `#5370 <https://github.com/jupyterlab/jupyterlab/pull/5370>`__, `#5363 <https://github.com/jupyterlab/jupyterlab/issues/5363>`__)
  * A JupyterLab application instance can now be given a document registry, service manager, and command linker. (`#5291 <https://github.com/jupyterlab/jupyterlab/pull/5291>`__)
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.34.12
  * add sidebar min-width css variable
  * use encodeURI instead of encodeURIComponent for shareable links
  * expand JupyterLab.IOptions to allow for custom DocumentRegistry
  * Rename package.json to package.json.orig when copying it to build folder
  * fix python versions of build wheels by removing the universal flag
  * Hide quit entry for older notebook versions
  * Notebook 4.3 Shim
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 0.34.7
  * Notebooks, consoles, and text files now have access to completions for local
    tokens.
  * Python 3.5+ is now required to use JupyterLab. Python 2 kernels can still be
    run within JupyterLab.
  * Added the pipe (``|``) character as a CSV delimiter option.
  * Added "Open From Path..."" to top level ``File`` menu.
  * Added "Copy Download Link" to context menu for files.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.33.4
  + Key Features:
  * No longer in beta
  * Workspaces
  * Menu items
  * Keyboard shortcuts
  * Command palette items
  * Settings
  * Larger file uploads
  * Extension management and installation
  * Interface changes
  * Renderers
  * Changes for developers
  * Other fixes
* Wed May  2 2018 jengelh@inai.de
- Trim filler wording from description.
- Replace bashisms in %%install.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.32.0
  * Better handling of a corrupted or invalid state database ([#3619](https://github.com/jupyterlab/jupyterlab/issues/3619), [#3622](https://github.com/jupyterlab/jupyterlab/issues/3622), [#3687](https://github.com/jupyterlab/jupyterlab/issues/3687), [#4114](https://github.com/jupyterlab/jupyterlab/issues/4114)).
  * Fixing file dirty status indicator ([#3652](https://github.com/jupyterlab/jupyterlab/issues/3652)).
  * New option for whether to autosave documents ([#3734](https://github.com/jupyterlab/jupyterlab/issues/3734)).
  * More commands in the notebook context menu ([#3770](https://github.com/jupyterlab/jupyterlab/issues/3770), [#3909](https://github.com/jupyterlab/jupyterlab/issues/3909))
  * Defensively checking for completion metadata from kernels ([#3888](https://github.com/jupyterlab/jupyterlab/issues/3888))
  * New "Shutdown all" button  in the Running panel ([#3764](https://github.com/jupyterlab/jupyterlab/issues/3764))
  * Performance improvements wherein non-focused documents poll the server less ([#3931](https://github.com/jupyterlab/jupyterlab/issues/3931))
  * Changing the keyboard shortcut for singled-document-mode to something less easy to trigger ([#3889](https://github.com/jupyterlab/jupyterlab/issues/3889))
  * Performance improvements for rendering text streams, especially around progress bars ([#4045](https://github.com/jupyterlab/jupyterlab/issues/4045)).
  * Canceling a "Restart Kernel" now functions correctly ([#3703](https://github.com/jupyterlab/jupyterlab/issues/3703)).
  * Defer loading file contents until after the application has been restored ([#4087](https://github.com/jupyterlab/jupyterlab/issues/4087)).
  * Ability to rotate, flip, and invert images in the image viewer ([#4000](https://github.com/jupyterlab/jupyterlab/issues/4000))
  * Major performance improvements for large CSV viewing ([#3997](https://github.com/jupyterlab/jupyterlab/issues/3997)).
  * Always show the context menu in the file browser, even for an empty directory ([#4264](https://github.com/jupyterlab/jupyterlab/issues/4264)).
  * Handle asynchronous comm messages in the services library more correctly (Note: this means `@jupyterlab/services` is now at version 2.0!) ([[#4115](https://github.com/jupyterlab/jupyterlab/issues/4115)](https://github.com/jupyterlab/jupyterlab/pull/4115)).
  * Display the kernel banner in the console when a kernel is restarted to mark the restart ([[#3663](https://github.com/jupyterlab/jupyterlab/issues/3663)](https://github.com/jupyterlab/jupyterlab/pull/3663)).
  * Many tweaks to the UI, as well as better error handling.
* Mon Mar 12 2018 toddrme2178@gmail.com
- Bugfixes.
- Update summary and description
- Package other version of extensions directory.
* Wed Feb 28 2018 toddrme2178@gmail.com
- Package extensions directory.
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
